@@ -1,5 +1,5 @@
 package App::JobLog::Command;
-$App::JobLog::Command::VERSION = '1.032';
+$App::JobLog::Command::VERSION = '1.033';
 # ABSTRACT: common functionality of App::JobLog commands
 
 use App::Cmd::Setup -command;
@@ -36,7 +36,7 @@ sub description {
     return $desc;
 }
 
-# performs text wrapping while preserving the formatting of lines beginning which whitespace
+# performs text wrapping while preserving the formatting of lines beginning with whitespace
 sub _wrap {
     my $desc = shift;
     require Text::WrapI18N;
@@ -84,6 +84,12 @@ sub options { }
 # by default a command does no argument validation
 sub validate { }
 
+# add to simple commands after argument signature so they'll complain if given arguments
+sub simple_command_check {
+    my ( $self, $args ) = @_;
+    $self->usage_error("This command does not expect any arguments! No action taken.") if @$args;
+}
+
 1;
 
 __END__
@@ -98,7 +104,7 @@ App::JobLog::Command - common functionality of App::JobLog commands
 
 =head1 VERSION
 
-version 1.032
+version 1.033
 
 =head1 DESCRIPTION
 
