@@ -1,5 +1,5 @@
 package App::JobLog::Command::info;
-$App::JobLog::Command::info::VERSION = '1.032';
+
 # ABSTRACT: provides general App::JobLog information
 
 use App::JobLog -command;
@@ -18,6 +18,7 @@ no if $] >= 5.018, warnings => "experimental::smartmatch";
 
 sub execute {
     my ( $self, $opt, $args ) = @_;
+    $self->simple_command_check($args);
     my ( $fh, $fn ) = tempfile( UNLINK => 1 );
     my ($executable) = reverse File::Spec->splitpath($0);
     my $text;
@@ -453,7 +454,7 @@ App::JobLog::Command::info - provides general App::JobLog information
 
 =head1 VERSION
 
-version 1.032
+version 1.033
 
 =head1 SYNOPSIS
 
