@@ -1,5 +1,5 @@
 package App::JobLog::Log::Note;
-$App::JobLog::Log::Note::VERSION = '1.032';
+$App::JobLog::Log::Note::VERSION = '1.033';
 # ABSTRACT: timestamped annotation in log
 
 
@@ -10,81 +10,93 @@ use autouse 'Carp'              => qw(carp);
 
 # for debugging
 use overload '""' => sub {
-    $_[0]->data->to_string;
+   $_[0]->data->to_string;
 };
 use overload 'bool' => sub { 1 };
 
 
 sub new {
-    my ( $class, $logline ) = @_;
-    $class = ref $class || $class;
-    my $self = bless { log => $logline }, $class;
-    return $self;
+   my ( $class, $logline ) = @_;
+   $class = ref $class || $class;
+   my $self = bless { log => $logline }, $class;
+   return $self;
 }
 
 
 sub clone {
-    my ($self) = @_;
-    my $clone = $self->new( $self->data->clone );
-    return $clone;
+   my ($self) = @_;
+   my $clone = $self->new( $self->data->clone );
+   return $clone;
 }
 
 
 sub data {
-    $_[0]->{log};
+   $_[0]->{log};
 }
 
 
 sub start : lvalue {
-    $_[0]->data->time;
+   $_[0]->data->time;
 }
 
 
 sub tags : lvalue {
-    $_[0]->data->{tags};
+   $_[0]->data->{tags};
+}
+
+
+sub tagged { !!@{ $_[0]->tags } }
+
+
+sub tag_list { @{ $_[0]->tags } }
+
+
+sub describe {
+   my ($self) = @_;
+   join '; ', @{ $self->data->description };
 }
 
 
 sub exists_tag {
-    my ( $self, @tags ) = @_;
-    $self->data->exists_tag(@tags);
+   my ( $self, @tags ) = @_;
+   $self->data->exists_tag(@tags);
 }
 
 
 sub all_tags {
-    my ( $self, @tags ) = @_;
-    $self->data->all_tags(@tags);
+   my ( $self, @tags ) = @_;
+   $self->data->all_tags(@tags);
 }
 
 
 sub cmp {
-    my ( $self, $other ) = @_;
-    carp 'argument must also be time' unless $other->isa(__PACKAGE__);
+   my ( $self, $other ) = @_;
+   carp 'argument must also be time' unless $other->isa(__PACKAGE__);
 
-    # defer to subclass sort order if other is a subclass and self isn't
-    return -$other->cmp($self)
-      if ref $self eq __PACKAGE__ && ref $other ne __PACKAGE__;
+   # defer to subclass sort order if other is a subclass and self isn't
+   return -$other->cmp($self)
+     if ref $self eq __PACKAGE__ && ref $other ne __PACKAGE__;
 
-    return DateTime->compare( $self->start, $other->start );
+   return DateTime->compare( $self->start, $other->start );
 }
 
 
 sub split_days {
-    return $_[0];
+   return $_[0];
 }
 
 
 sub intersects {
-    my ( $self, $other ) = @_;
-    if ($other->can('end')) {
-        return $self->start >= $other->start && $self->start < $other->end;
-    }
-    return $self->start == $other->start;
+   my ( $self, $other ) = @_;
+   if ( $other->can('end') ) {
+      return $self->start >= $other->start && $self->start < $other->end;
+   }
+   return $self->start == $other->start;
 }
 
 
 sub is_open { 0 }
- 
+
 1;
 
 __END__
@@ -99,7 +111,7 @@ App::JobLog::Log::Note - timestamped annotation in log
 
 =head1 VERSION
 
-version 1.032
+version 1.033
 
 =head1 DESCRIPTION
 
@@ -128,6 +140,18 @@ Start of event. Is lvalue method.
 
 Tags of event (array reference). Is lvalue method.
 
+=head2 tagged
+
+Whether there are any tags.
+
+=head2 tag_list
+
+Returns tags as list rather than reference.
+
+=head2 describe
+
+Returns the log line's description.
+
 =head2 exists_tag
 
 Expects a list of tags. Returns true if event contains any of them.
